import{_ as e,n as s,s as l,x as a}from"./index-zaYCB7m6.js";import"./c.CzGI896K.js";import"./c.B41VBpbv.js";import"./c.Dfz7XRSh.js";let o=class extends l{render(){return a`
      <esphome-process-dialog
        heading="Clean All Files"
        .type=${"clean-all"}
        .spawnParams=${{clean_build_dir:!0}}
        @closed=${this._handleClose}
      ></esphome-process-dialog>
    `}_handleClose(){this.parentNode.removeChild(this)}};o=e([s("esphome-clean-all-dialog")],o);
//# sourceMappingURL=c.Crde2sDH.js.map
