import{U as s,V as a}from"./index-zaYCB7m6.js";const i="wifi_ssid",n="wifi_password",o=async()=>{const a=await s();return a.includes(i)&&a.includes(n)},r=async(s,o)=>a({[i]:s,[n]:o},"Your Wi-Fi SSID and password");export{n as S,i as a,o as c,r as s};
//# sourceMappingURL=c.fZJwopKZ.js.map
