import{_ as o,e,n as i,s,x as t}from"./index-zaYCB7m6.js";import"./c.CzGI896K.js";import"./c.B41VBpbv.js";import"./c.Dfz7XRSh.js";let r=class extends s{render(){return t`
      <esphome-process-dialog
        .heading=${`Clean MQTT discovery topics for ${this.configuration}`}
        .type=${"clean-mqtt"}
        .spawnParams=${{configuration:this.configuration}}
        @closed=${this._handleClose}
      >
      </esphome-process-dialog>
    `}_handleClose(){this.parentNode.removeChild(this)}};o([e()],r.prototype,"configuration",void 0),r=o([i("esphome-clean-mqtt-dialog")],r);
//# sourceMappingURL=c.7Mbgj2o8.js.map
